Index: /issm/trunk-jpl/src/m/classes/plotoptions.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/plotoptions.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/classes/plotoptions.m	(revision 19336)
@@ -104,5 +104,5 @@
 
 					 %get suplot(s) associated
-					 string=strsplit(rawlist{i,1},'#');
+					 string=strsplit_strict(rawlist{i,1},'#');
 					 plotnums=string{end};
 					 field=string{1};
@@ -127,5 +127,5 @@
 							 %pound i-j
 						 elseif ismember('-',plotnum)
-							 nums=strsplit(plotnum,'-');
+							 nums=strsplit_strict(plotnum,'-');
 							 if length(nums)~=2, continue; end
 							 if ~isnumeric(nums)
Index: /issm/trunk-jpl/src/m/plot/plot_tensor_components.m
===================================================================
--- /issm/trunk-jpl/src/m/plot/plot_tensor_components.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/plot/plot_tensor_components.m	(revision 19336)
@@ -69,5 +69,5 @@
 	%apply options
 	if ismember('_',type) %user plotet stress_tensor
-		strings=strsplit(type,'_');
+		strings=strsplit_strict(type,'_');
 		string=strings{1};
 	else %default plot: user requested stress
Index: /issm/trunk-jpl/src/m/plot/plot_tensor_principal.m
===================================================================
--- /issm/trunk-jpl/src/m/plot/plot_tensor_principal.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/plot/plot_tensor_principal.m	(revision 19336)
@@ -67,5 +67,5 @@
 %apply options
 if ismember('_',type) %user plotet stress_tensor
-	strings=strsplit(type,'_');
+	strings=strsplit_strict(type,'_');
 	string=strings{1};
 else %default plot: user requested stress
Index: /issm/trunk-jpl/src/m/plot/plot_tensor_principalaxis.m
===================================================================
--- /issm/trunk-jpl/src/m/plot/plot_tensor_principalaxis.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/plot/plot_tensor_principalaxis.m	(revision 19336)
@@ -89,5 +89,5 @@
 
 %apply options
-strings=strsplit(type,'_');
+strings=strsplit_strict(type,'_');
 string=strings{1};
 options=addfielddefault(options,'title',[upper(string(1)) string(2:end) ' principal axis ' type(end)]);
Index: /issm/trunk-jpl/src/m/plot/plot_vstime.m
===================================================================
--- /issm/trunk-jpl/src/m/plot/plot_vstime.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/plot/plot_vstime.m	(revision 19336)
@@ -6,5 +6,5 @@
 %getting the variable structure
 datastruct  = getfieldvalue(options,'Input');
-structnames = strsplit(datastruct,'.');
+structnames = strsplit_strict(datastruct,'.');
 
 %getting the position of the to be ploted point
Index: /issm/trunk-jpl/src/m/solve/parseresultsfromdisk.py
===================================================================
--- /issm/trunk-jpl/src/m/solve/parseresultsfromdisk.py	(revision 19335)
+++ /issm/trunk-jpl/src/m/solve/parseresultsfromdisk.py	(revision 19336)
@@ -39,4 +39,5 @@
 	result=ReadData(fid)
 	while result:
+		print result['step']
 		if   result['step'] > len(results):
 			for i in xrange(len(results),result['step']-1):
Index: sm/trunk-jpl/src/m/string/strsplit.m
===================================================================
--- /issm/trunk-jpl/src/m/string/strsplit.m	(revision 19335)
+++ 	(revision )
@@ -1,88 +1,0 @@
-function splittedstring = strsplit(inpstr,delimiter)
-%STRSPLIT - split a tring of delimiter separated values
-%
-%   This function should be used to split a string of delimiter separated
-%   values.  If all values are numerical values the returned matrix is a
-%   double array but if there is one non numerical value a cell array is
-%   returned.  You can check this with the iscell() function.
-%   inpstr: string containing delimiter separatede numerical values, eg
-%           3498,48869,23908,34.67
-%   Output: An x by 1 matrix containing the splitted values
-%   Delimiter: optional, if omitted the delimiter is , (comma)
-%
-%   Usage:
-%      output = strsplit(inpstr[,delimiter])
-%
-
-%   mailto:    gie.spaepen@ua.ac.be
-
-%Check input arguments
-if(nargin < 1)
-    error('There is no argument defined');
-else
-    if(nargin == 1)
-        strdelim = ',';
-        %Verbose off!! disp 'Delimiter set to ,';
-    else
-        strdelim = delimiter;
-    end
-end
-
-%deblank string
-deblank(inpstr);
-
-%Get number of substrings
-idx  = findstr(inpstr,strdelim);
-if size(idx) == 0
-    disp 'No delimiter in string, inputString is returned';
-    splittedstring = inpstr;
-else
-    %Define size of the indices
-    sz = size(idx,2);
-    %Define splittedstring
-    tempsplit = {};
-    %Loop through string and itinerate from delimiter to delimiter
-    for i = 1:sz
-        %Define standard start and stop positions for the start position,
-        %choose 1 as startup position because otherwise you get an array
-        %overflow, for the endposition you can detemine it from the
-        %delimiter position
-        strtpos = 1;
-        endpos = idx(i)-1;
-        %If i is not the beginning of the string get it from the delimiter
-        %position
-        if i ~= 1
-            strtpos = idx(i-1)+1;
-        end
-        %If i is equal to the number of delimiters get the last element
-        %first by determining the lengt of the string and then replace the
-        %endpos back to a standard position
-        if i == sz
-            endpos = size(inpstr,2); 
-            tempsplit(i+1) = {inpstr(idx(i)+1 : endpos)};
-            endpos = idx(i)-1;
-        end
-        %Add substring to output: splittedstring a cell array
-        tempsplit(i) = {inpstr(strtpos : endpos)};   
-    end
-    %Flag 
-    isallnums = 1;
-    %Check is there are NaN values if matrix elements are converted to
-    %doubles
-    for i = 1:size(tempsplit,2)
-        tempdouble = str2double(tempsplit(i));
-        if(isnan(tempdouble))
-            isallnums = 0;
-        end
-    end
-    %If isallnums = 1 then return a double array otherwise return a cell
-    %array
-    if(isallnums == 1)
-        for i = 1:size(tempsplit,2)
-            splittedstring(i) = str2double(tempsplit(i));
-        end
-    else
-        splittedstring = tempsplit;
-    end
-
-end
Index: /issm/trunk-jpl/src/m/string/strsplit_strict.m
===================================================================
--- /issm/trunk-jpl/src/m/string/strsplit_strict.m	(revision 19335)
+++ /issm/trunk-jpl/src/m/string/strsplit_strict.m	(revision 19336)
@@ -1,4 +1,4 @@
-function splittedstring = strsplit(inpstr,delimiter)
-%STRSPLIT - split a tring of delimiter separated values
+function splittedstring = strsplit_strict(inpstr,delimiter)
+%STRSPLIT_STRICT - split a string of delimiter separated values
 %
 %   Usage:
